import os
import sys
from redis import StrictRedis
from logging import Logger

class CloeePyRedis(object):
    def __init__(self, config:dict, log:Logger):
        # make copy of redis configuration and add auto-decoding configuration
        params = config.copy()
        params['encoding'] = 'utf-8'
        params['decode_responses'] = True

        # set pluginNamespace
        self._namespace = "redis"
        if "pluginNamespace" in params:
            self._namespace = params["pluginNamespace"]
            del params["pluginNamespace"]

        # use environment variables for username and password if they exist
        if  "CLOEEPY_REDIS_PASSWORD" in os.environ:
            log.info("CloeePy-Redis: Using password defined in environment")
            params['password'] = os.environ['CLOEEPY_REDIS_PASSWORD']

        log.info("CloeePy-Redis: Dialing Redis")
        self.conn = StrictRedis(**params)

        pong = self.conn.ping()
        if pong == True:
            log.info("CloeePy-Redis: Established connection to Redis")
        else:
            msg = "CloeePy-Redis: Failed to establish connection to Redis"
            log.error(msg)
            sys.exit(msg)


    def get_namespace(self):
        return self._namespace

    def get_value(self):
        return self.conn



from distutils.core import setup

setup(
    name='CloeePy-Redis',
    version='0.0.0',
    packages=['cloeepy_redis',],
    package_data = {
        'cloeepy_redis': ['data/*.yml'],
    },
    license='MIT',
    description="Plugin for CloeePy Framework",
    long_description=open('README.md').read(),
    install_requires=[
        "redis>=2,<3",
        "CloeePy>=0",
     ],
     url = "https://github.com/cloeeai/CloeePy-Redis",
     author = "Scott Crespo",
     author_email = "sccrespo@gmail.com",
     keywords = "mini framework cloee cloeepy redis",
     python_requires='~=3.3',
)



import os
import unittest
from cloeepy import CloeePy
from cloeepy_redis.cloeepy_redis import CloeePyRedis

class TestCloeePyMongo(unittest.TestCase):

    def setUp(self):
        config_path = os.path.join(os.path.dirname(__file__), "data/config.yml")
        os.environ["CLOEEPY_CONFIG_PATH"] = config_path

    def test_init(self):
        app = CloeePy()
        self.assertTrue(hasattr(app, "log"))
        self.assertTrue(hasattr(app, "config"))
        self.assertTrue(hasattr(app, "redis"))
        self.assertTrue(app.redis.ping())

if __name__ == "__main__":
    unittest.main()
